/*
 *  subtitle editor
 *	http://kitone.free.fr/subtitleeditor/
 *
 *  Copyright @ 2005-2006, IDJAAD Djamel (aka Kitone)
 *
 *  Contact: kitone at free point fr
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  See gpl.txt for more information regarding the GNU General Public License.
 *
 *
 *  \file
 *  \brief 
 *  \author IDJAAD Djamel (kitone at free point fr)
 */

#include <iostream>
#include <gtkmm/main.h>
#include <gtkmm/window.h>
#include <gtkmm/table.h>
#include <gtkmm/scrolledwindow.h>
#include <gtkmm/box.h>
#include <gtkmm/spinbutton.h>
#include <gtkmm/dialog.h>
#include <gtkmm/label.h>

#include "SubtitleView.h"
#include "SubtitleEditor.h"

#include <glibmm/spawn.h>

#include <glibmm.h>

#include <gtkmm/liststore.h>
#include <gtkmm/stock.h>

#include "ASpell.h"
#include "SpellDialog.h"
#include <config.h>

#include "SubtitleSSA.h"
#include "utility.h"
#include "Config.h"

#include <locale.h>


/*
 *
 */
class SubtitleOption : public Glib::OptionGroup
{
public:
  SubtitleOption();

public:
  Glib::ustring	m_subtitlefile;
  Glib::ustring m_moviefile;
	bool m_maximize;
};

/*
 *
 */
SubtitleOption::SubtitleOption()
:Glib::OptionGroup("subtitleeditor", "description ....", "help...")
{
	m_maximize = false;
	
  Glib::OptionEntry entry1;
  entry1.set_long_name("maximize");
  entry1.set_description("Maximize window");
  add_entry(entry1, m_maximize);

  Glib::OptionEntry entry2;
  entry2.set_long_name("sub");
  entry2.set_short_name('s');
  entry2.set_description("The subtitle file");
  add_entry(entry2, m_subtitlefile);

  Glib::OptionEntry entry3;
  entry3.set_long_name("movie");
  entry3.set_short_name('m');
  entry3.set_description("The movie file");
  add_entry(entry3, m_moviefile);
}


void check_default_config()
{
	Config &cfg = Config::getInstance();
	// encodings encodings
	if(!cfg.has_key("encodings", "default"))
	{
		Glib::ustring encodings="ISO-8859-15;UTF-8;";
		cfg.set_value_string("encodings", "encodings", encodings);
	}
	// encodings default
	if(!cfg.has_key("encodings", "default"))
	{
		std::string def;
		if(!Glib::get_charset(def))
			def="UTF-8";

		cfg.set_value_string("encodings", "default", def);
	}
}

/*
 *
 */
int main(int argc, char *argv[])
{

	// piti check...
  Glib::ustring path_se = Glib::build_filename(Glib::get_home_dir(), ".subtitleeditor");
  if(Glib::file_test(path_se, Glib::FILE_TEST_IS_DIR) == false)
  {
    Glib::ustring cmd = "mkdir " + path_se;
    system(cmd.c_str());
  }

	bindtextdomain(PACKAGE, PACKAGE_LOCALE_DIR);
  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
	textdomain(PACKAGE);

	g_set_application_name("subtitleeditor");

	Gtk::Main kit(argc, argv);

	
  SubtitleOption options;
  Glib::OptionContext context;
  
  context.set_main_group(options);

  try
  {
    context.parse(argc, argv);
  }
  catch(const Glib::Error &ex)
  {
    std::cout << "SubtitleEditor::Exception: " << ex.what() << std::endl;
    return 1;
  }

	debug_msg("main : check_default_config");
	
	check_default_config();

	debug_msg("main : create SubtitleEditor instance");

	SubtitleEditor* editor = SubtitleEditor::getInstance();	

	if(!options.m_subtitlefile.empty())
		editor->open_subtitle(options.m_subtitlefile);
	if(!options.m_moviefile.empty())
		editor->open_movie(options.m_moviefile);	
	if(options.m_maximize)
		editor->maximize();

	debug_msg("main : run");
  kit.run(*editor);

	debug_msg("main : delete subtitleeditor");
	delete editor;
  return 0;
}

